@@ -14,7 +14,7 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.00';
+$VERSION = '1.02';
 
 # FITS tags (ref 1)
 %Image::ExifTool::FITS::Main = (
@@ -36,6 +36,10 @@ $VERSION = '1.00';
    'TIME-OBS'=> { Name => 'ObservationTime',    Groups => { 2 => 'Time' } },
    'DATE-END'=> { Name => 'ObservationDateEnd', Groups => { 2 => 'Time' } },
    'TIME-END'=> { Name => 'ObservationTimeEnd', Groups => { 2 => 'Time' } },
+    COMMENT  => { Name => 'Comment', PrintConv => '$val =~ s/^ +//; $val',
+                  Notes => 'leading spaces are removed if L<PrintConv|../ExifTool.html#PrintConv> is enabled' },
+    HISTORY  => { Name => 'History', PrintConv => '$val =~ s/^ +//; $val',
+                  Notes => 'leading spaces are removed if L<PrintConv|../ExifTool.html#PrintConv> is enabled' },
 );
 
 #------------------------------------------------------------------------------
@@ -67,13 +71,20 @@ sub ProcessFITS($$)
             last if $key eq 'END';
             # make sure the key is valid
             $key =~ /^[-_A-Z0-9]*$/ or $et->Warn('Format error in FITS header'), last;
-            next unless substr($buff,8,2) eq '= ';  # ignore comment lines
+            if ($key eq 'COMMENT' or $key eq 'HISTORY') {
+                my $val = substr($buff, 8); # comments start in column 9
+                $val =~ s/ +$//;            # remove trailing spaces
+                $et->HandleTag($tagTablePtr, $key, $val);
+                next;
+            }
+            # ignore other lines that aren't tags
+            next unless substr($buff,8,2) eq '= ';
             # save tag name (avoiding potential conflict with ExifTool variables)
             $tag = $Image::ExifTool::specialTags{$key} ? "_$key" : $key;
             # add to tag table if necessary
             unless ($$tagTablePtr{$tag}) {
                 my $name = ucfirst lc $tag; # make tag name lower case with leading capital
-                $name =~ s/_(.)/\U$1/g;     # remove all '_' and capitalize subsquent letter
+                $name =~ s/_(.)/\U$1/g;     # remove all '_' and capitalize subsequent letter
                 AddTagToTable($tagTablePtr, $tag, { Name => $name });
             }
         }
@@ -126,7 +137,7 @@ information from FITS (Flexible Image Transport System) images.
 
 =head1 AUTHOR
 
-Copyright 2003-2019, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2023, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
